@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
 import datetime
 
 from django.contrib.auth import get_user_model
@@ -7,7 +6,6 @@ from django.contrib.auth.models import Group
 from django.core.cache import cache
 from django.db import models
 from django.db.models import Q
-from django.utils.encoding import python_2_unicode_compatible
 
 import reversion
 from tinymce.models import HTMLField
@@ -16,7 +14,6 @@ User = get_user_model()
 
 
 @reversion.register()
-@python_2_unicode_compatible
 class Notification(models.Model):
     SIGN_COMPANY = 'SIGN_COMPANY'
     SIMPLE_OK = 'SIMPLE_OK'
@@ -145,10 +142,9 @@ class Notification(models.Model):
 
 
 @reversion.register()
-@python_2_unicode_compatible
 class UserNotification(models.Model):
-    user = models.ForeignKey(User)
-    notification = models.ForeignKey(Notification)
+    user = models.ForeignKey(User, on_delete=models.CASCADE)
+    notification = models.ForeignKey(Notification, on_delete=models.CASCADE)
     seen = models.BooleanField(default=False)
     timestamp = models.DateTimeField(auto_now_add=True)
     next_display = models.DateTimeField(default=None, null=True, blank=True)
